@@ -1,13 +1,13 @@
 package Getopt::Long::Patch::DumpAndExit;
 
-our $DATE = '2015-01-02'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-27'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 no warnings;
 
-use Data::Dump;
+use Data::Dmp;
 use Module::Patch 0.19 qw();
 use base qw(Module::Patch);
 
@@ -15,7 +15,7 @@ our %config;
 
 sub _dump {
     print "# BEGIN DUMP $config{-tag}\n";
-    dd @_;
+    say dmp($_[0]);
     print "# END DUMP $config{-tag}\n";
 }
 
@@ -101,7 +101,7 @@ Getopt::Long::Patch::DumpAndExit - Patch Getopt::Long to dump option spec and ex
 
 =head1 VERSION
 
-This document describes version 0.04 of Getopt::Long::Patch::DumpAndExit (from Perl distribution Getopt-Long-Dump), released on 2015-01-02.
+This document describes version 0.05 of Getopt::Long::Patch::DumpAndExit (from Perl distribution Getopt-Long-Dump), released on 2015-09-27.
 
 =head1 DESCRIPTION
 
